@@ -407,7 +407,7 @@ class SubmitServer:
                elif ldapHost.startswith("ldap://"):
                   ldapObject = ldap.initialize(ldapHost)
                else:
-                  ldapObject = ldap.open(ldapHost)
+                  ldapObject = ldap.initialize("ldap://"+ldapHost)
             except ldap.LDAPError,msg:
                log("%s: %s" % (ldapHost,msg))
                continue
